@@ -1,7 +1,13 @@
 from luna.baseLunaUtils import BaseLunaUtils
+from luna.logging.localLunaLogger import LocalLunaLogger
 import os
 
 class LocalLunaUtils(BaseLunaUtils):
+    
+    def Init(self, luna_config, run_mode, args, userInput):
+        super().Init(luna_config, run_mode, args, userInput)
+        self._logger = LocalLunaLogger()
+        
     def RegisterModel(self, model_path, description, luna_python_model=None):
         # do nothing
         return
