@@ -32,7 +32,7 @@ def RegisterModel(model_path, description, args):
         experiment = Run.get_context(allow_offline=False).experiment
         ws = experiment.workspace
 
-        model = Model.register(model_path = model_path,
+        Model.register(model_path = model_path,
                        model_name = args.modelId,
                        description = description,
                        workspace = ws,
